from flask.ext.wtf import Form
from wtforms.fields import TextField, SelectField, TextAreaField
from wtforms.validators import URL, Required, AnyOf, Regexp

class AddEventForm(Form):
    metadata_url = TextField(u'Metadata URL', validators = [URL()])

class EnterResultFormTC(Form):
    username = TextField(u'Username', validators = [Required()])
    col_1 = TextField(u'Profile')

    result = SelectField(
                u'Result',
                choices = [
                    ('', '-- Select Result --'),
                    ('PASSED', 'PASSED'),
                    ('FAILED', 'FAILED'),
                    ('INFO', 'INFO')
                ],
                validators = [
                    AnyOf(('PASSED', 'FAILED', 'INFO'))
                ],
             )

    bugs = TextField(
              u'Bugs',
              validators = [
                  Regexp(r"^([0-9]+;?)*$",
                         message ="Please enter bug numbers divided by semicolons. i.e. '752855;25532'",
                        )
                  ],
              #help_text = "Bug numbers divided by semicolons, e.g. '752855;25532'"
           )

    comment = TextAreaField(u'Comment')

    def __init__(self, col_1_name=None, *args, **kwargs):
        super(EnterResultFormTC, self).__init__(*args, **kwargs)
        if col_1_name is not None:
            self.col_1.label.text = col_1_name

class EnterResultFormTXT(Form):
    username = TextField(u'Username', validators = [Required()])
    col_1 = TextField(u'Profile')

    result = TextField(u'Result', validators = [Required()])

    bugs = TextField(
              u'Bugs',
              validators = [
                  Regexp(r"^([0-9]+;?)*$",
                         message ="Please enter bug numbers divided by semicolons. i.e. '752855;25532'",
                        )
                  ],
              #help_text = "Bug numbers divided by semicolons, e.g. '752855;25532'"
           )

    comment = TextAreaField(u'Comment')

    def __init__(self, col_1_name=None, *args, **kwargs):
        super(EnterResultFormTXT, self).__init__(*args, **kwargs)
        if col_1_name is not None:
            self.col_1.label.text = col_1_name

def EnterResultForm(testcase):
    if testcase.type == 'txt':
        return EnterResultFormTXT(testcase.category.col_1_name)
    else:
        return EnterResultFormTC(testcase.category.col_1_name)
