#!/usr/bin/python
# wiki.py - wiki interaction module for autoqa

import fedora.client
from urlparse import urljoin
import urllib
import simplejson

def __strip_url(url):
    for s in ["https://fedoraproject.org/wiki/", fedora.client.wiki.Wiki().base_url]:
        if url.startswith(s):
            url = url[len(s):]
    return url

def __get_sections(page):
    page = __strip_url(page)
    w = fedora.client.wiki.Wiki()
    params = {'action':'parse',
              'format':'json',
              'prop':'sections',
              'text':'{{:%s}}__TOC__' % page}
    result = w.send_request('api.php', req_params=params)
    return result['parse']['sections']

def __read_page_section(page, secnum):
    page = __strip_url(page)
    w = fedora.client.wiki.Wiki()
    # w.send_request chokes if it doesn't get json data back, so we can't
    # use that.
    params = {'action':'raw','templates':'expand','section':secnum,'title':page}
    url = urljoin(w.base_url, 'index.php')
    url += '?' + urllib.urlencode(params, doseq=True)
    section = urllib.urlopen(url)
    return section.read()

def get_page_section(page, secname):
    page = __strip_url(page)
    secnum = None
    secname = secname.lower()
    for s in __get_sections(page):
        if s['line'].lower().strip() == secname:
            secnum = s['number']
    if not secnum:
        return None
    return __read_page_section(page, secnum)


def wiki_json_parse(sectiondata):
    decoder = simplejson.JSONDecoder()
    jsonitems = []
    # TODO: this could be more robust. We could parse each line by itself
    # and then merge all the valid lines at the end, rather than completely
    # dying if there's any invalid data..
    for line in sectiondata.split("\n"):
        if line.startswith('*'):
            jsonitems.append(line[1:].strip())
        elif jsonitems:
            break
    jsondata = '{' + ','.join(jsonitems) + '}'
    data = decoder.decode(jsondata)
    return data

def get_autoqa_metadata(page):
    page = __strip_url(page)
    section = get_page_section(page, 'autoqa metadata')
    if section is None:
        return dict()
    return wiki_json_parse(section)


if __name__ == '__main__':
    import pprint
    page = 'User:Jskladan/Sandbox:TestdayAppTemplate'
    print "Fetching metadata from %s" % page
    pprint.pprint(get_page_section(page, 'TestdayApp Metadata'))
