# Copyright 2014, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#    Josef Skladanka <jskladan@redhat.com>

import datetime

from testdays import db

TESTCASE_TYPES = ('tc', 'txt')

class Event(db.Model):

    id = db.Column(db.Integer, primary_key=True)
    name = db.Column(db.Text)
    metadata_url = db.Column(db.Text)
    testday_url = db.Column(db.Text)
    resultsdb_job_id = db.Column(db.Integer)
    created_at = db.Column(db.DateTime, default = datetime.datetime.utcnow)

    categories = db.relation('Category', backref='event', order_by='Category.id')

    def __init__(self, name, metadata_url, testday_url=None, resultsdb_job_id=None):
        self.name = name
        self.metadata_url = metadata_url
        self.testday_url = testday_url
        self.resultsdb_job_id = resultsdb_job_id

class Category(db.Model):

    __table_args__ = (
            db.Index('category_fk_event_id', 'event_id'),
            )

    id = db.Column(db.Integer, primary_key=True)
    event_id = db.Column(db.Integer, db.ForeignKey('event.id'))
    name = db.Column(db.Text)
    col_1_name = db.Column(db.Text)

    testcases = db.relation('Testcase', backref='category', order_by='Testcase.id')

    def __init__(self, name, event=None):
        self.name = name
        if event is not None:
            self.event = event

class Testcase(db.Model):

    __table_args__ = (
            db.Index('testcase_fk_category_id', 'category_id'),
            )

    id = db.Column(db.Integer, primary_key=True)
    category_id = db.Column(db.Integer, db.ForeignKey('category.id'))
    name = db.Column(db.Text)
    url = db.Column(db.Text)
    type = db.Column(db.Enum(*TESTCASE_TYPES, name='testcase_type'))

    def __init__(self, name, url, type, category=None):
        self.name = name
        self.type = type
        self.url = url
        if category is not None:
            self.category = category

